@@ -1,6 +1,6 @@
-from typing import Any, Callable
+from typing import Any, Callable, List, Optional
 
-from graphql.type import (
+from graphql import (
     GraphQLArgument,
     GraphQLField,
     GraphQLInputType,
@@ -8,31 +8,34 @@ from graphql.type import (
     GraphQLList,
     GraphQLNonNull,
     GraphQLResolveInfo,
+    get_nullable_type,
 )
 
+__all__ = ["plural_identifying_root_field"]
+
 
 def plural_identifying_root_field(
     arg_name: str,
     input_type: GraphQLInputType,
     output_type: GraphQLOutputType,
     resolve_single_input: Callable[[GraphQLResolveInfo, str], Any],
-    description: str = None,
+    description: Optional[str] = None,
 ) -> GraphQLField:
-    if isinstance(input_type, GraphQLNonNull):
-        input_type = input_type.of_type
-    input_args = {
-        arg_name: GraphQLArgument(
-            GraphQLNonNull(GraphQLList(GraphQLNonNull(input_type)))
-        )
-    }
-
-    def resolve(_obj, info, **args):
+    def resolve(_obj: Any, info: GraphQLResolveInfo, **args: Any) -> List:
         inputs = args[arg_name]
         return [resolve_single_input(info, input_) for input_ in inputs]
 
     return GraphQLField(
         GraphQLList(output_type),
         description=description,
-        args=input_args,
+        args={
+            arg_name: GraphQLArgument(
+                GraphQLNonNull(
+                    GraphQLList(
+                        GraphQLNonNull(get_nullable_type(input_type))  # type: ignore
+                    )
+                )
+            )
+        },
         resolve=resolve,
     )
